package com.caimei.service;

import com.caimei.model.ResponseJson;
import com.caimei.model.vo.ClubUserVo;
import com.caimei.model.vo.ClubVo;
import com.caimei.model.vo.WxClubListVo;
import com.github.pagehelper.PageInfo;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
public interface AuthClubService {

    /**
     * 机构列表
     *
     * @param authUserId    供应商用户id
     * @param clubName      机构名称
     * @param pageNum       第几页
     * @param pageSize      一页多少条
     * @return AuthVo
     */
    ResponseJson<PageInfo<ClubVo>> getClubList(Integer authUserId, String clubName, Integer pageNum, Integer pageSize);

    /**
     * 机构用户列表
     * @param authId    机构id
     * @param mobile    手机号
     * @param status    状态：1未绑定，2已绑定，3已过期
     * @param pageNum   第几页
     * @param pageSize  一页多少条
     * @return  ClubUserVo
     */
    ResponseJson<PageInfo<ClubUserVo>> getClubUserList(Integer authId, String mobile, Integer status, Integer pageNum, Integer pageSize);

    /**
     * 生成邀请码
     * @param authId
     * @return
     */
    ResponseJson generateCode(Integer authId);

    /**
     * 解绑邀请码
     * @param clubUserId
     * @return
     */
    ResponseJson unbindCode(Integer clubUserId);

    /**
     * 更新邀请码
     * @param clubUserId
     * @return
     */
    ResponseJson updateCode(Integer clubUserId);

    /**
     * 微信公众号机构列表
     * @param appId         供应商公众号appId
     * @param clubName      机构名称
     * @param pageNum       第几页
     * @param pageSize      一页多少条
     * @return
     */
    ResponseJson<PageInfo<WxClubListVo>> getWxClubList(String appId, String clubName, Integer pageNum, Integer pageSize);

    /**
     * 提交反馈
     * @param clubUserId    机构用户id
     * @param content       反馈内容
     * @return
     */
    ResponseJson submitFeedback(Integer clubUserId, String content);
}
