package com.caimei.service;

import com.caimei.model.ResponseJson;
import com.caimei.model.vo.FileListVo;
import com.caimei.model.vo.WxFileListVo;
import com.github.pagehelper.PageInfo;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/7/8
 */
public interface FileService {

    /**
     * 获取文件列表
     *
     * @param listType      列表类型：1文件列表，2文件审核列表
     * @param authUserId    供应商用户id
     * @param fileTitle    文件标题
     * @param auditStatus   审核状态
     * @param status        上线状态
     * @param pageNum       第几页
     * @param pageSize      一页多少条
     * @return  FileVo
     */
    ResponseJson<PageInfo<FileListVo>> getFileList(Integer listType, Integer authUserId, String fileTitle, Integer auditStatus, Integer status, Integer pageNum, Integer pageSize);

    /**
     * 添加/编辑文件
     * @param fileId           文件id
     * @param authUserId        供应商用户id
     * @param fileTitle        文件标题
     * @param fileName        文件名称
     * @param filePreviewUrl      文件预览链接
     * @param fileDownloadUrl       文件下载链接
     * @return  ResponseJson
     */
    ResponseJson saveFile(Integer fileId, Integer authUserId, String fileTitle, String fileName, String filePreviewUrl, String fileDownloadUrl);

    /**
     * 更新文件状态
     * @param fileId       文件id
     * @param status        文件状态:0停用 1启用
     * @return  ResponseJson
     */
    ResponseJson updateFileStatus(Integer fileId, Integer status);

    /**
     * 删除文件
     * @param fileId     文件id
     * @return  ResponseJson
     */
    ResponseJson deleteFile(Integer fileId);

    /**
     * 审核文件
     * @param fileId           文件id
     * @param auditStatus       审核状态：0审核未通过，1审核通过，2待审核
     * @param invalidReason     审核不通过原因
     * @param auditBy           审核人用户id
     * @return
     */
    ResponseJson auditFile(Integer fileId, Integer auditStatus, String invalidReason, Integer auditBy);

    /**
     * 微信公众号文件列表
     * @param authUserId        供应商用户id
     * @param fileTitle          文件名称
     * @param pageNum           第几页
     * @param pageSize          一页多少条
     * @return
     */
    ResponseJson<PageInfo<WxFileListVo>> getWxFileList(Integer authUserId, String fileTitle, Integer pageNum, Integer pageSize);

    void download();
}
